package multex; //Assertion.java

//History:
//2000-09-29  Knabe  Creation

/**Tool for checking unexpected programming errors*/
public class Assertion {

/**Do not create objects of me!*/
private Assertion(){}

/**Checks, that i_condition holds.
* <H3>Note:</H3>
* If you want to give diagnostic parameters to an Assertion, you should yourself
* write the code e.g.<PRE>
*   if(!condition){
*     throw new Assertion.Failure(name, stringPar1, new Integer(intPar2));
*   }
* </PRE>
* This should not be committed to a check-Method, because creating a new
* capsule object for each parameter of a primitive type involves to much
* overhead in non-error cases, too.
*/
public static void check(
  final boolean i_condition,   final String i_name
)throws Assertion.Failure {
  if(!i_condition){
    throw new Assertion.Failure(i_name);
  }
}//check


/**Indicates that an assertion failed. An assertion should always be true.
  Any failing of an assertion thus has to be considered as a programming error.
  You should use assertions for indicating the violation of invariants or
  postconditions. For indicating the violation of a precondition you should
  better use individually named exceptions.
*/
public static class Failure extends multex.Failure {
  /**The name of the failed Assertion, mostly it should be the failed condition
    as a String
  */
  public /*JDK1.2:final*/ String name;

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object[] i_parameters)
  {super("Failure of Assertion {name}", (Exception)null, i_parameters); name = i_name; }

  /**Indicates that the assertion i_name failed*/
  public Failure(final String i_name){this(i_name,null);}

 /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0)
  {this(i_name, new Object[]{i_par0});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1)
  {this(i_name, new Object[]{i_par0,i_par1});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6
  });}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6, Object i_par7)
  {this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6,
  i_par7});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6, Object i_par7,
    Object i_par8
  ){this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6,
  i_par7,i_par8});}

  /**Indicates that the assertion i_name failed with parameters*/
  public Failure(String i_name, Object i_par0, Object i_par1, Object i_par2,
    Object i_par3, Object i_par4, Object i_par5, Object i_par6, Object i_par7,
    Object i_par8, Object i_par9
  ){this(i_name, new Object[]{i_par0,i_par1,i_par2,i_par3,i_par4,i_par5,i_par6,
  i_par7,i_par8,i_par9});}
}



}//Assertion