package multex; //MethodFailure.java

//History:
//2000-10-15  Knabe  Created from class Failure. All convenience constructors
//                   were taken here.


/**Convenience class, which can be
  directly used to be thrown by any failed method. It has always
  the same message: "Failure in operation {methodName} in class {className}".
  The named exception parameters should be derived automatically from the
  stack trace (???not yet implemented).
  <P><B>Attention:</B>The usage of this convenience class is comfortable,
  but not recommended. You would get better user messages by defining
  individual exceptions with a specific message text for the failure of
  each method, which can be triggered by user action. For exceptions of the
  lower tiers this holds the same. You should also consider to define a
  Failure-exception for each unit (class or package) of the lower tiers.
  Then it would be easier to catch and handle exceptions from this unit
  the same way.
  @author Christoph Knabe, knabe@tfh-berlin.de, TFH Berlin, 2000 Copyrighted
*/

public class MethodFailure extends Failure {



/** Constructs a MethodFailure-exception, giving only the causing Exception object.
*/
public MethodFailure(
  final Exception i_cause
){
  this(i_cause, null);
}

/**Constructs a MethodFailure-exception, giving the causing Exception object for
  providing the diagnostics causer chain and unnamed message parameters as an
  Object[].
  The preferred way to parameterize a Failure exception is by named parameters,
  which is described at {@link Failure#Failure(String,Exception)}
  Nevertheless you can shortly create unnamed message parameters by creating
  an Object[] holding the unnamed parameters, e.g.:

  <PRE><CODE>
* try{
*   ... //many calls to service methods
* } catch(Exception ex){ //all these are unexpected
*     throw new MethodFailure(ex, new Object[]{new Integer(i_size), i_element});
*   }
* //end try
  </PRE></CODE>
*/
public MethodFailure(
  final Exception i_cause, final Object[] i_unnamedParameters
){
  super(
    //"Failure in operation {methodName} in class {className}", ???
    "Operation failed",
    i_cause, i_unnamedParameters
  );
}


}//MethodFailure