//Copy.java

//Change history:
//2000-09-29  Knabe  Nur noch benannte Ausnahmeparameter
//2000-07-24  Knabe  Test von benannten Ausnahmeparametern
//2000-07-04  Knabe  CopyFailure beerbt multex.Failure statt Exc
//1999-03-24  Knabe  Exc-Parameter als Object[]
//1999-01-15  Knabe  Als Demo fuer Exc: Ausnahme mit History und Parameter
//1998-12-14  Knabe  Umbau zu binaer Kopieren
//1998-03-10  Knabe  Erstellung als Cat

import multex.Exc;
import multex.Msg;
import multex.Failure;

/** Kopiert eine Datei, siehe Methode main().
  Dient als Demo zur Umdefinition einer von unten kommenden Ausnahme in eine
  Ausnahme der eigenen Abstraktionsebene, ohne die Diagnoseinformationen der
  verursachenden Ausnahme zu unterdrcken.
  Hier wird in copy() jede IOException umdefiniert nach CopyFailure.
  Da CopyFailure Failure beerbt und die verursachende Ausnahme ueber seinen
  Konstruktor an Failure weitergibt, kann bei Nichtbehandlung von CopyFailure
  durch den Aufrufer main() mittels printStackTrace() die gesamte Diagnoseinfo
  sowohl der verursachenden IOException als auch des abstrahierten Kopierfehlers
  gemeldet werden.
  Ausserdem hat CopyFailure zwei Parameter:
  <P>{inFileName}=Name der Eingabedatei, {outFileName}=Name der Ausgabedatei

  <P>Beispieldialog:
<code><pre>
*  C:\>java -Djava.compiler= Copy eingabe ausgabe
*  The file "eingabe" could not be copied to "ausgabe"
*  CAUSE: java.io.FileNotFoundException: eingabe (Das System kann die angegebene Datei nicht finden)
*  -----Stack trace follows-----
*  java.io.FileNotFoundException: eingabe (Das System kann die angegebene Datei nicht finden)
*          at java.io.FileInputStream.open(Native Method)
*          at java.io.FileInputStream.<init>(FileInputStream.java:68)
*          at Copy.copy(Copy.java:80)
*  WAS CAUSING:
*  Copy$CopyFailure: {inFileName}=eingabe  {outFileName}=ausgabe
*          at Copy.copy(Copy.java:93)
*          at Copy.main(Copy.java:49)
*          at ...
*  C:\>
</pre></code>
*/

public class Copy {
  /**Effect: Copies the file i_args[0] in binary mode to file i_args[1].*/
  public static void main(final String[] i_args){
    try{copy(i_args[0], i_args[1]);}
      catch(Exception ex){
        Msg.report(ex);
        System.err.println("-----Stack trace follows-----");
        Msg.printStackTrace(ex);
      }
    //end try
  }

  /**Indicates, that this test driver has been started. If your environment
    is set to language "de", then the message text from the german message
    text file MsgText_de.properties will be taken instead of this default
    message text defined here.*/
  public static class StartedExc extends Exc {
    public final String driver;
    public final java.util.Date date;
    public StartedExc(final String i_driver, final java.util.Date i_date){
      super("Copy-driver {driver}, version of {date,date} was started");
      driver = i_driver;
      date = i_date;
    }
  }

  /**Indicates failure of a file copy operation*/
  public static class CopyFailure extends Failure {
    public final String inFileName;
    public final String outFileName;
    public CopyFailure(
      final Exception i_cause,
      final String    i_inFileName,
      final String    i_outFileName
    ){
      super("File '{inFileName}' could not be copied to '{outFileName}'",i_cause);
      inFileName = i_inFileName;
      outFileName = i_outFileName;
    }
  }//CopyFailure

  /**Effect: Copies the file i_inFileName in binary mode to file i_outFileName.
  */
  public static void copy(
    final String i_inFileName,
    final String i_outFileName
  ) throws CopyFailure
  {
    try{
      final java.io.FileInputStream inStream
      = new java.io.FileInputStream(i_inFileName);
      final java.io.FileOutputStream outStream
      = new java.io.FileOutputStream(i_outFileName);
      final byte[] buf = new byte[512];

      for(;;){
        final int len = inStream.read(buf);
        if(len<=0){break;}
        outStream.write(buf,0,len);
      }
      inStream.close();
      outStream.close();
    } catch(final Exception ex){
        throw new CopyFailure(ex, i_inFileName, i_outFileName);
      }
    //end try
  }//copy


/**Do not create objects of me!*/
private Copy(){}

}//Copy